ngNRC
=================

.. currentmodule:: pynrc.simul.ngNRC

.. rubric:: Summary

.. autosummary::

    ~pynrc.simul.ngNRC.SCAnoise
    ~pynrc.simul.ngNRC.slope_to_ramp

.. rubric:: Documentation

.. autofunction:: pynrc.simul.ngNRC.SCAnoise
.. autofunction:: pynrc.simul.ngNRC.slope_to_ramp
